class ElementorAbandonedForm {
    constructor() {
        this.init();
    }

    init() {
        document.addEventListener('DOMContentLoaded', () => {
            this.listenForAbandonedForms();
        });
    }

    hasAncestorTagOrAttribute(element, tagName, attributeName, attributeValue) {
        while (element) {
            if (element.tagName && element.tagName.toLowerCase() === tagName.toLowerCase()) {
                return true;
            }
            if (element.hasAttribute(attributeName) && element.getAttribute(attributeName) === attributeValue) {
                return true;
            }
            element = element.parentElement;
        }
        return false;
    }
    listenForAbandonedForms() {
        const forms = document.querySelectorAll('.elementor-form');
        forms.forEach(form => {
            let formLocation = 'page';
            if (this.hasAncestorTagOrAttribute(form, 'header', '', '')) {
                formLocation = 'header';
            } else if (this.hasAncestorTagOrAttribute(form, 'footer', '', '')) {
                formLocation = 'footer';
            } else if (this.hasAncestorTagOrAttribute(form, '', 'data-elementor-type', 'popup')) {
                formLocation = 'popup';
            }
            const formId = form.querySelector('input[name="form_id"]').value;
            const formFields = form.querySelectorAll('input, textarea');
            let formSubmitted = false;
            let formFocused = false;

            // Listen for focus events on form fields
            formFields.forEach(field => {
                field.addEventListener('focus', () => {
                    formFocused = true;
                });
            });

            // Listen for form submission
            form.addEventListener('submit', () => {
                formSubmitted = true;
            });

            // Detect when user try to leave the page without submitting the form
            window.addEventListener('beforeunload', event => {
                // Check if formFocused is true (indicating user interaction with the form)
                // and formSubmitted is false (indicating the form wasn't submitted)
                if (formFocused && !formSubmitted) {
                    // Trigger the function to handle abandoned form
                    this.callServerHook(formId, formLocation);
                }
            });
        });
    }

    callServerHook(formData, formLocation) {
        const baseUrl = `${data.baseUrl}/wp-json/emp-plugin/v1/elementor/abandoned`;
        jQuery.ajax({
            url: baseUrl,
            data: {
                formId: formData,
                formLocation: formLocation
            },
            method: 'POST',
            success: function (response) {
            },
            error: function (error) {
                console.log(error);
            }
        });
    }
}

const elementorAbandonedForm = new ElementorAbandonedForm();
