class WPFormsAbandonedForm {
    constructor() {
        this.init();
    }

    init() {
        document.addEventListener('DOMContentLoaded', () => {
            this.listenForAbandonedForms();
        });
    }


    // Function to check if an element has a specific ancestor tag or attribute
    hasAncestorTagOrAttribute(element, tagName, attributeName, attributeValue) {
        while (element) {
            if (element.tagName && element.tagName.toLowerCase() === tagName.toLowerCase()) {
                return true;
            }
            if (element.hasAttribute(attributeName) && element.getAttribute(attributeName) === attributeValue) {
                return true;
            }
            element = element.parentElement;
        }
        return false;
    }
    listenForAbandonedForms() {
        const forms = document.querySelectorAll('.wpforms-container');

        forms.forEach(formContainer => {
            let formLocation = 'page';
            if (this.hasAncestorTagOrAttribute(formContainer, 'header', '', '')) {
                formLocation = 'header';
            } else if (this.hasAncestorTagOrAttribute(formContainer, 'footer', '', '')) {
                formLocation = 'footer';
            } else if (this.hasAncestorTagOrAttribute(formContainer, '', 'data-elementor-type', 'popup')) {
                formLocation = 'popup';
            }
            const formId = formContainer.getAttribute('id').replace('wpforms-', '');
            const formFields = formContainer.querySelectorAll('input, textarea');
            let formSubmitted = false;
            let formFocused = false;

            // Function to check if an element has a specific ancestor tag

            // Listen for focus events on form fields
            formFields.forEach(field => {
                field.addEventListener('focus', () => {
                    formFocused = true;
                });
            });

            // Listen for form submission
            const formElement = formContainer.querySelector('form');
            formElement.addEventListener('submit', () => {
                formSubmitted = true;
            });

            // Detect when user tries to leave the page without submitting the form
            window.addEventListener('beforeunload', event => {
                // Check if formFocused is true (indicating user interaction with the form)
                // and formSubmitted is false (indicating the form wasn't submitted)
                if (formFocused && !formSubmitted) {
                    // Trigger the function to handle abandoned form
                    this.callServerHook(formId, formLocation);
                }
            });
        });
    }

    callServerHook(formData, formLocation) {
        const baseUrl = `${data.baseUrl}/wp-json/emp-plugin/v1/wpforms/abandoned`;
        jQuery.ajax({
            url: baseUrl,
            data: {
                formId: formData,
                formLocation: formLocation
            },
            method: 'POST',
            success: function (response) {
            },
            error: function (error) {
                console.log(error)
            }
        });
    }
}

const wpAbandonedForm = new WPFormsAbandonedForm();
