class WPFormsViewedForm {
    constructor() {
        this.init();
    }

    init() {
        document.addEventListener('DOMContentLoaded', () => {
            this.listenForViewedForms();
        });
    }

    hasAncestorTagOrAttribute(element, tagName, attributeName, attributeValue) {
        while (element) {
            if (element.tagName && element.tagName.toLowerCase() === tagName.toLowerCase()) {
                return true;
            }
            if (element.hasAttribute(attributeName) && element.getAttribute(attributeName) === attributeValue) {
                return true;
            }
            element = element.parentElement;
        }
        return false;
    }

    listenForViewedForms() {
        const forms = document.querySelectorAll('.wpforms-container');
        forms.forEach(formContainer => {
            const formId = formContainer.getAttribute('id').replace('wpforms-', '');
            let formLocation = 'page';

            if (this.hasAncestorTagOrAttribute(formContainer, 'header', 'data-elementor-type', 'header')) {
                formLocation = 'header';
            } else if (this.hasAncestorTagOrAttribute(formContainer, 'footer', 'data-elementor-type', 'footer')) {
                formLocation = 'footer';
            } else if (this.hasAncestorTagOrAttribute(formContainer, '', 'data-elementor-type', 'popup')) {
                formLocation = 'popup';
            }

            const formElement = formContainer.querySelector('form');
            if (!formElement) {
                // console.error('Form element not found inside formContainer:', formContainer);
                return;
            }
            const hiddenInput = document.createElement('input');

            hiddenInput.type = 'hidden';
            hiddenInput.name = 'formLocation';
            hiddenInput.value = formLocation;

// Append the hidden input to the form
            formElement.appendChild(hiddenInput);

            const hiddenCount = document.createElement('input');
            hiddenCount.type = 'hidden';
            hiddenCount.name = 'hiddenCount';
            hiddenCount.value = '0';
            formElement.appendChild(hiddenCount);

            let formViewed = false;
            // Check if the form is initially in the viewport
            if (isElementInViewport(formContainer) && !formViewed) {
                this.callServerHook(formId, formLocation);
                formViewed = true;
            }

            // Listen for scroll events to detect if the form is in the viewport
            window.addEventListener('scroll', () => {
                if (isElementInViewport(formContainer) && !formViewed) {
                    this.callServerHook(formId, formLocation);
                    formViewed = true;
                }
            });

            formElement.addEventListener('submit', () => {
                if (hiddenCount.value !== "0") {
                    this.callServerHook(formId, formLocation);
                }

                const num = parseInt(hiddenCount.value) + 1;
                hiddenCount.value = num.toString();
            });

            // Helper function to check if an element is in the viewport
            function isElementInViewport(element) {
                const rect = element.getBoundingClientRect();
                const result = (
                    rect.top < (window.innerHeight || document.documentElement.clientHeight) &&
                    rect.left < (window.innerWidth || document.documentElement.clientWidth) &&
                    rect.bottom > 0 &&
                    rect.right > 0
                );
                return result;
            }
        });
    }

    callServerHook(formData,formLocation) {
        const baseUrl = `${data.baseUrl}/wp-json/emp-plugin/v1/wpforms/viewed`;
        jQuery.ajax({
            url: baseUrl,
            data: {
                formId: formData,
                formLocation: formLocation,
            },
            method: 'POST',
            success: function (response) {
            },
            error: function (error) {
                console.log(error);
            }
        });
    }
}

const wpViewedForm = new WPFormsViewedForm();
