<?php

namespace Send\Classes\Database;

class Database
{
	public function __construct()
	{
		$this->bootEloquent();
	}

    static function execute($query, $extractField = false, $field = null) {
        global $wpdb;
        // Get the SQL string from the query builder
        $sql = $query->toSql();
        // Get bindings from the query builder
        $bindings = $query->getBindings();
        // Replace bindings in SQL query
        $replacedSql = $sql;

        foreach ($bindings as $binding) {
            $escapedBinding = $wpdb->prepare('%s', $binding);
            $replacedSql = preg_replace('/\?/', $escapedBinding, $replacedSql, 1);
        }
        // Execute the SQL query using $wpdb
        $results = $wpdb->get_results($replacedSql);  // phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared
        return $results;
    }

	static function fields($fieldNames, $res) {
		$payload = [];
		foreach ($res as $item) {
			$fields = [];
			foreach ($fieldNames as $fieldName) {
				$fields[$fieldName] = $item->$fieldName;
			}
			$payload[] = $fields;
		}
		return $payload;
	}
    static function field($fieldName, $res) {
        $payload = [];
        foreach ($res as $item) {
            $payload[] = $item->$fieldName;
        }
        return $payload;
    }

    private function bootEloquent() {
        $capsule = new \Illuminate\Database\Capsule\Manager;
        global $wpdb;
        $capsule->addConnection([
            'driver'    => 'mysql',
            'host'      => DB_HOST,
            'database'  => DB_NAME,
            'Database'  => DB_NAME, //  vendor problem. hacky way to fix.
            'username'  => DB_USER,
            'password'  => DB_PASSWORD,
            'charset'   => DB_CHARSET,
            'collation' => 'utf8_unicode_ci',
            'prefix'    => $wpdb->prefix,
        ]);
        $capsule->setAsGlobal();
        $capsule->bootEloquent();
    }
}

$database = new Database();
