<?php

namespace Send\Classes\Integrations\Forms;

use Send\Classes\Database\Database;
use Send\Classes\Database\Models\Post;
use Send\Classes\Database\Models\PostMeta;
use Send\Classes\Traits\Submission;
use Send;

class ElementorForms extends Forms
{
    public $sourceName = 'elementor';
    public $name = 'Elementor';
    private static $instance = null;

    function __construct()
    {
        $this->resetState();
    }
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self();
        }
        return self::$instance;
    }


    function resetState()
    {
        $this->pluginFile = 'elementor/elementor.php';
        if (!function_exists('is_plugin_active')) {
            require_once(ABSPATH . '/wp-admin/includes/plugin.php');
        }

        if (self::isPluginActive()) {
            parent::__construct($this->name);
        }

        if (isset($this->pluginData)) {
            $this->pluginData['logoPath'] = plugins_url('/app/Assets/images/elementor.svg', Send::$pluginDir);
        }
        $this->init();
    }

    public function init()
    {
        if (self::isPluginActive()) {
            $this->active = true;
            add_action('elementor_pro/forms/new_record', [$this, 'onFormSubmit'], 10, 2);
        }
    }

    public static function isPluginActive()
    {
        if (!function_exists('is_plugin_active')) {
            require_once(ABSPATH . '/wp-admin/includes/plugin.php');
        }
        return is_plugin_active('elementor/elementor.php');
    }

    function onFormSubmit($record)
    {
        $fields = $record->get('fields');
        $formId = $record->get_form_settings('id');
        $formName = $record->get_form_settings('form_name');
        $fieldsData = [];
        foreach ($fields as $field) {
            $fieldsData[$field['id']] = $field['value'];
        }
        $payload = [$formId, $formName, $fieldsData];
        Submission::sendFormSubmissionData($payload, $this->sourceName);
    }

    static function getAllIds()
    {
        return self::getAllFormsMeta();
    }

    static function findAllFormsPosts()
    {
        $query = PostMeta::where('meta_key', '_elementor_data')
            ->where('meta_value', 'LIKE', '%"widgetType":"form"%');
        $results = Database::execute($query);
        return $results;
    }

    static function getAllFormsMeta()
    {
        $formsPosts = self::findAllFormsPosts();
        $formPostsIds = [];
        $payload = [];
        foreach ($formsPosts as $formPost) {
            $formPostsIds[] = $formPost->post_id;
            $contents = json_decode($formPost->meta_value);

            foreach ($contents as $content) {
                self::extractForms($content, $formPost->post_id, $payload);
            }
        }
        return $payload;
    }

    private static function extractForms($element, $postId, &$payload)
    {
        if (isset($element->widgetType) && $element->widgetType === 'form') {
            $formId = $element->id;
            $payload[$postId][] = $formId;
            $payload[$postId]['fields'] = $element->settings->form_fields;
            $payload[$postId]['form_name'] = $element->settings->form_name;
        }

        if (isset($element->elements) && is_array($element->elements)) {
            foreach ($element->elements as $childElement) {
                self::extractForms($childElement, $postId, $payload);
            }
        }
    }

    static function getAllForms()
    {
        $formsIds = self::getAllIds();
        $formsData = [];

        foreach ($formsIds as $page => $formId) {
            $formName = $formId['form_name'];
            $post = Post::where('ID', $page)
                ->whereNotIn('post_type', ['revision'])
                ->where('post_status', 'publish');
            $results = Database::execute($post);

            if (empty($results)) {
                continue;
            }

            $formPagesData = [];
            $pageData = [
                'pageId' => strval($page),
                'name' => get_the_title($page),
                'permalink' => get_permalink($page),
                'pageType' => self::getFormLocation($formId[0])
            ];
            $formPagesData[] = $pageData;

            $formsData[] = [
                'formId' => $formId,
                'pages' => $formPagesData,
                'formName' => $formName,
            ];
        }
        return $formsData;
    }

    static function getFormLocation($formId)
    {
        $query = Post::where('post_type', 'elementor_library')
            ->where('post_status', 'publish');
        $results = Database::execute($query);

        foreach ($results as $result) {
            $id = $result->ID;
            $postMeta = PostMeta::where('post_id', $id)
                ->where('meta_key', '_elementor_data');
            $metaResults = Database::execute($postMeta);

            foreach ($metaResults as $metaResult) {
                $containers = json_decode($metaResult->meta_value);

                foreach ($containers as $container) {
                    if (isset($container->elements)) {
                        foreach ($container->elements as $element) {
                            if (!isset($element->isInner)) {
                                if (isset($element->widgetType) && $element->widgetType == 'form') {
                                    if ($element->id == $formId) {
                                        $libType = PostMeta::where('post_id', $id)
                                            ->where('meta_key', '_elementor_template_type');
                                        $libTypeResults = Database::execute($libType);
                                        $libTypeResults = $libTypeResults[0]->meta_value;
                                        return $libTypeResults;
                                    }
                                }
                            } else {
                                foreach ($element->elements as $innerElement) {
                                    if (isset($innerElement->widgetType) && $innerElement->widgetType == 'form') {
                                        if ($innerElement->id == $formId) {
                                            $libType = PostMeta::where('post_id', $id)
                                                ->where('meta_key', '_elementor_template_type');
                                            $libTypeResults = Database::execute($libType);
                                            $libTypeResults = $libTypeResults[0]->meta_value;
                                            return $libTypeResults;
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        return 'page';
    }

    static function getPagesOfForm($formId)
    {
        $query = Post::whereIn('post_type', ['page', 'elementor_library'])
            ->where('ID', $formId);
        $results = Database::execute($query);
        return $results;
    }

    public static function getAllData($syncMethod = 'form')
    {
        if (!self::isPluginActive()) {
            return [];
        }

        $allData = self::getAllForms();
        $payload = [];
        foreach ($allData as $form) {
            $formData = [];
            $formId = $form['formId'][0];
            $formData['formId'] = strval($formId);
            $formData['formName'] = $form['formName'];
            $formData['pages'] = $form['pages'];
            $formData['fields'] = [];
            foreach ($form['formId']['fields'] as $index => $field) {
                if (!isset($field->field_type)) {
                    if (!isset($field->field_label)) {
                        continue;
                    }
                    $field->field_type = 'text';
                }
                $formData['fields'][] = [
                    'type' => $field->field_type,
                    'fieldName' => $field->field_label,
                    'orderInForm' => $index,
                    'isRequired' => isset($field->required) ? boolval($field->required) : false,
                ];
            }
            $formData['source'] = [
                'method' => $syncMethod,
                'name' => 'elementor',
            ];
            $payload[] = $formData;
        }

        return $payload;
    }
}
