<?php

namespace Send\Classes\Integrations\Forms;
use Send\Classes\Database\Database;
use Send\Classes\Database\Models\Post;
use Send\Classes\Database\Models\PostMeta;
use Send\Classes\Traits\Submission;
use Send;


class WpForms extends Forms
{
	public $sourceName = 'wpforms';
	public $name = 'WPForms';
    private static $instance = null;

    public function __construct()
	{
		$this->resetState();
	}

	function resetState($isConnected = false) {
		if (!function_exists('is_plugin_active')) {
			require_once(ABSPATH . '/wp-admin/includes/plugin.php');
		}

		$this->init();
		if (self::isPluginActive()) {
            parent::__construct($this->name);
        }

		if (isset($this->pluginData)) {
			$this->pluginData['logoPath'] = plugins_url( '/app/Assets/images/wpforms.svg', Send::$pluginDir );
		}
	}

    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /*
        Check if WPForms plugin is active
        @return bool
    */
	public function init() {
		// Check if WPForms plugin is active
			if (self::isLite()) {
				$this->pluginFile = 'wpforms-lite/wpforms.php';
			} else {
				$this->pluginFile = 'wpforms/wpforms.php';
			}
		if (self::isPluginActive()) {
			$this->active = true;
			// The WPForms plugin is active, proceed with initializing the action
			add_action('wpforms_process_complete', [$this, 'onFormSubmit'], 10, 4);
		}
	}
	public static function isPluginActive()
	{
		if (!function_exists('is_plugin_active')) {
			require_once(ABSPATH . '/wp-admin/includes/plugin.php');
		}
		return is_plugin_active('wpforms/wpforms.php') || is_plugin_active('wpforms-lite/wpforms.php');
	}
	public static function isLite() {
		return is_plugin_active('wpforms-lite/wpforms.php') || file_exists(WP_PLUGIN_DIR . '/' . 'wpforms-lite/wpforms.php');
	}


    function onFormSubmit( $fields, $entry, $form, $entryId)
	{
        // Construct the log message
		$formId = $form['id'];
		$formName = $form['settings']['form_title'];
		$fieldsData = [];
        foreach ( $fields as $field ) {
			$fieldsData[$field['name']] = $field['value'];
        }
		$payload = [$formId, $formName, $fieldsData];
		Submission::sendFormSubmissionData($payload,$this->sourceName);
    }


    static function getPagesOfForm($form)
    {
        $res = Post::where('post_content', 'like', '%wpforms-' . $form->ID . '%')
            ->whereIn('post_type', ['page','elementor_library'])
			->where('post_status','publish');
        return Database::execute($res);
    }



    static function getWpForms()
    {
        $query = Post::where('post_type', 'wpforms');
        return Database::execute($query);
    }
    static function getAllForms()
    {
        $wpFormsData = [];
        $wpForms = self::getWpForms();
        if ($wpForms) {
            foreach ($wpForms as $form) {
                $formPagesData = [];
                $pages = self::getPagesOfForm($form);
                foreach ($pages as $page) {
                    $pageData = [
                        'pageId' => strval($page->ID),
                        'name' => $page->post_name,
                        'permalink' => get_permalink($page->ID),
						'pageType' => self::getPageType($page->ID),
                    ];
                    $formPagesData[] = $pageData;
                }
                $wpFormsData[] = [
                    'formId' => $form->ID,
                    'formName' => $form->post_name,
                    'pages' => $formPagesData
                ];
            }
        }
		return $wpFormsData;
    }

	public static function getAllData($syncMethod = 'form')
	{
		if (!self::isPluginActive()) {
			return [];
		}
		$forms = self::getAllForms();
		$allFormsFields = self::getAllFormsFields();
		$payload = [];
		foreach ($forms as $form) {
			$formId = strval($form['formId']);
			$form['fields'] = $allFormsFields[$formId]['fields'];
			$form['source'] = [
				'method' => $syncMethod,
				'name' => 'wpforms',
			];
			$payload[] = $form;
		}
		return $payload ? $payload : [];
	}

	static function getAllFormsFields()
	{
		// Check if WPForms plugin is active
		if (class_exists('WPForms')) {
			// Get all WPForms
			$wpForms = WPForms()->form->get();
			// Initialize an array to store form data
			$formsData = [];
			// Ensure $wpForms is an array
			if (is_array($wpForms)) {
				// Loop through each form
				foreach ($wpForms as $wpForm) {
					// Ensure $wpForm is an object
					if (is_object($wpForm)) {
						$formId = $wpForm->ID;
						$formName = $wpForm->post_title;
						// Get form object
						$form = wpforms()->form->get( $formId );
						$postContent = $form->post_content;
						$data = json_decode($postContent, true);
						$fieldsData = $data['fields'];
						$fields = [];
						// Loop through each form field
						foreach ($fieldsData as $index => $field) {
							// Add field data to the fields array
							$fields[] = [
								'type' => $field['type'],
								'fieldName' => strval($field['label']),
								'orderInForm' => $index,
								'isRequired' => isset($field['required']) ? boolval($field['required']) : false,
							];
						}
						// Store form fields in the formsData array using the form ID as the key
						$formsData[$formId] = [
							'source' => 'wpforms',
							'formId' => strval($formId),
							'formName' => $formName,
							'fields' => $fields,
							'numberOfFields' => count($fields),
						];
					}
				}
			}

			return $formsData;
		} else {
			// WPForms plugin is not active
			return [];
		}
	}


}
