<?php

namespace Send\Classes\Integrations\WooCommerce\Components;

use Send\Classes\Database\Database;
use Send\Classes\Database\Models\WCCustomer;
use Send\Classes\Integrations\WooCommerce\Sync_Base;
use Send\Classes\Traits\Woo;

class WooCustomers extends Sync_Base {

	const ENTITY = 'customer';

	static function sync() {
         self::getAllCustomers();
    }

    public static function getAllCustomers() {
        $maxMemoryPerChunk = 300 * 1024 * 1024; // 300MB in bytes
        $sampleSize = 10; // Number of customers to sample
        $page = 0;

        // Fetch a small sample of customers to estimate average size
        $offset = 0;
        $query = WCCustomer::where('customer_id', '>', 0)
            ->limit($sampleSize)
            ->offset($offset);
        $sampleCustomers = Database::execute($query);

        // Calculate the memory usage of the sample
        $sampleMemoryUsage = memory_get_usage();
        $customerSampleSize = count($sampleCustomers);

        foreach ($sampleCustomers as $customer) {
            $sampleMemoryUsage += strlen(serialize($customer));
        }

        if ($customerSampleSize === 0) {
            error_log('No customers found');
            return;
        }
        // Estimate average size per customer
        $averageCustomerSize = $sampleMemoryUsage / $customerSampleSize;

        // Calculate the chunk size based on the 50MB memory limit
        $chunkSize = floor($maxMemoryPerChunk / $averageCustomerSize);

        $customersFound = true;

        while ($customersFound) {
            $offset = $page * $chunkSize;
            $query = WCCustomer::where('customer_id', '>', 0)
                ->limit($chunkSize)
                ->offset($offset);
            $customers = Database::execute($query);

            if ($customers) {
                Woo::sendInitialSyncData(['items' => $customers], 'sync data (activate plugin)', static::ENTITY);
                $page++;
            } else {
                $customersFound = false;
                if ($page == 0) {
                    error_log('No customers found');
                }
            }
        }
    }

	protected function get_next_page( bool $is_first ): array {
		// TODO: Implement get_next_page() method.
		// should fetch all the site users or just from the lookup?
		// see: WC_REST_Customers_V1_Controller::get_items()
		return [];
	}

}
