<?php

namespace Send\Classes\Scripts;

class ScriptsLoader
{

	public function loadAppScripts() {
		$this->enqueueAppScripts();
		$this->enqueueAppStyles();
	}

	public function loadTrackings()
	{
		// if inside the wp admin no need to load the tracking scripts
		if (!is_admin()) {
			// Localize script with the ajaxurl
            wp_enqueue_script('jquery');
			$this->loadCf7Tracking();
			$this->loadWPFormsTracking();
			$this->loadElementorFormsTracking();

			$this->loadUserTracking();
		}
	}
	private function loadUserTracking() {
		$this->registerTrackingScript(
			'emp-plugin-user-tracking', // Handle
			SEND_PLUGIN_BASE_URL . JS_FOLDER . 'user/tracking/user-behavior.js', // Script URL
			array(), // Dependencies
			'1.0', // Version
			true // Load script in the footer
		);
		wp_localize_script('emp-plugin-user-tracking', 'wpApiSettings', array(
			'root' => esc_url_raw(rest_url()),
			'nonce' => wp_create_nonce('wp_rest')
		));
	}

	private function loadElementorFormsTracking() {
		$this->registerTrackingScript(
			'emp-plugin-elementor-abandoned-form-tracking', // Handle
			SEND_PLUGIN_BASE_URL . JS_FOLDER . 'forms/tracking/elementor/abandoned-form.js', // Script URL
			array(), // Dependencies
			'1.0', // Version
			true // Load script in the footer
		);
		$this->registerTrackingScript(
			'emp-plugin-elementor-viewed-form-tracking', // Handle
			SEND_PLUGIN_BASE_URL . JS_FOLDER . 'forms/tracking/elementor/viewed-form.js', // Script URL
			array(), // Dependencies
			'1.0', // Version
			true // Load script in the footer
		);
	}

	private function loadWPFormsTracking() {

		$this->registerTrackingScript(
			'emp-plugin-wpforms-abandoned-form-tracking', // Handle
			SEND_PLUGIN_BASE_URL . JS_FOLDER . 'forms/tracking/wpforms/abandoned-form.js', // Script URL
			array(), // Dependencies
			'1.0', // Version
			true // Load script in the footer
		);

		$this->registerTrackingScript(
			'emp-plugin-wpforms-viewed-form-tracking', // Handle
			SEND_PLUGIN_BASE_URL . JS_FOLDER . 'forms/tracking/wpforms/viewed-form.js', // Script URL
			array(), // Dependencies
			'1.0', // Version
			true // Load script in the footer
		);

	}

	private function registerTrackingScript($handle, $script_url, $dependencies = array(), $version = '1.0', $in_footer = true) {
		wp_register_script(
			$handle,
			$script_url,
			$dependencies,
			$version,
			$in_footer
		);
		// put https in the url if the url doesnt contain http or https, but if it's local env put only http
        $protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off') || $_SERVER['SERVER_PORT'] == 443 ? 'https://' : 'http://';
        $baseUrl = $protocol . CURRENT_HOST;
        wp_localize_script(
			$handle,
			'data',
			array('baseUrl' => $baseUrl)
		);
		wp_enqueue_script($handle);
	}

	private function loadCf7Tracking() {
		$this->registerTrackingScript(
			'emp-plugin-cf7-abandoned-form-tracking', // Handle
			SEND_PLUGIN_BASE_URL . JS_FOLDER . 'forms/tracking/cf7/abandoned-form.js', // Script URL
			array(), // Dependencies
			'1.0', // Version
			true // Load script in the footer
		);
		$this->registerTrackingScript(
			'emp-plugin-cf7-viewed-form-tracking', // Handle
			SEND_PLUGIN_BASE_URL . JS_FOLDER . 'forms/tracking/cf7/viewed-form.js', // Script URL
			array(), // Dependencies
			'1.0', // Version
			true // Load script in the footer
		);
	}

	private function enqueueAppScripts()
	{
		// Register and enqueue your JavaScript file with type="module"
		wp_register_script(
			'emp-plugin-script', // Handle
			SEND_PLUGIN_BASE_URL . JS_FOLDER . JS_ENTRY, // Script URL
			[], // Dependencies (if any)
			PLUGIN_VERSION, // Version
			true // Load script in the footer
		);
        // put https in the url if the url doesnt contain http or https, but if it's local env put only http
        $protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off') || $_SERVER['SERVER_PORT'] == 443 ? 'https://' : 'http://';
        $baseUrl = $protocol . CURRENT_HOST;
		wp_localize_script(
			'emp-plugin-script',
			'data',
			array('baseUrl' => $baseUrl, 'iframeUrl' => IFRAME_URL)
		);
		wp_enqueue_script('emp-plugin-script');
		add_filter("script_loader_tag", array($this, "addModuleToScript"),
			10, 3);
	}

	private function enqueueAppStyles()
	{
		// Register and enqueue your CSS file
		wp_register_style(
			'emp-plugin-style', // Handle
			SEND_PLUGIN_BASE_URL . CSS_FOLDER . CSS_ENTRY, // Script URL
			[], // Dependencies (if any)
			PLUGIN_VERSION // Version
		);

		wp_enqueue_style('emp-plugin-style');
	}

// Callback function to add type="module" to your script
	public function addModuleToScript($tag, $handle, $src)
	{
		if (strpos($handle, 'emp-plugin') !== false) {
			$tag = '<script type="module" src="'.esc_url($src).'"></script>';
		}
		return $tag;
	}
}
