<?php
namespace Send\Classes\Traits;
use connect\classes\Config;
use connect\classes\data;
use connect\classes\GrantTypes;
use connect\classes\service;
use connect\classes\Utils;
use connect\Client;
use connect\classes\exceptions\Service_Exception;

trait Connect {

    public static function getCurrency()
    {
        $currency = '$';
        // Hook into 'woocommerce_loaded' which fires after WooCommerce is initialized
        add_action('woocommerce_loaded', function () use (&$currency) {
            // Double-check if WooCommerce and the function are available
            if (function_exists('get_woocommerce_currency')) {
                error_log('get_woocommerce_currency() is available: ' . get_woocommerce_currency());
                $currency = get_woocommerce_currency();
            } else {
                error_log('get_woocommerce_currency() is not available');
            }
        });

        return $currency;
    }
    /**
     * register site on site collection
     */
    public static function register_site_on_collection($token) {
        // TODO: move out of here
        $currency = self::getCurrency();
        $request_payload = [
            'siteUrl' => strval(CURRENT_HOST),
            'token' => $token,
            'currency' => $currency
        ];

        
        try {
            $client = new Client();
            $url = API_ENDPOINT . '/sites';
            // TODO-1: check if site exits on collection and if so - skip the site creation
            $response = $client->make_request('POST', $url, $request_payload);
            if (is_wp_error($response) || isset($response->errors)) {
                // TODO-2: only after TODO-1, if failed to create site, stop the process clear all tokens and throw an exception to avoid creating plugins etc...
                // if site duplication error (409 duplicate error)- skip the site creation and continue
                // if site creation failed - stop the process and throw an exception
                // throw new Service_Exception('Failed to create site on collection');
            }
            error_log('Site registered on collection: ' . json_encode($response));

            return $response;
        } catch (\Exception $e) {
            // couldn't register site on collection - delete the client registration
            // TODO: add deactivation license also
            service::disconnect();
            error_log('Error registering site on collection: ' . $e->getMessage());
            throw $e;
        }
    }

    public static function should_show_connect() {
        $page = null;

        if ( !is_admin() ) {
            return false;
        }

        if (isset($_GET['page'])) {
            $page = $_GET['page'];
        }

        if ( Config::ADMIN_PAGE !== $page ) {
            return false;
        }

        return true;
    }

    public static function should_handle_auth_code(): bool {
		global $plugin_page;

		$page_slug = explode( 'page=', Config::ADMIN_PAGE );

        if (!self::should_show_connect()) {
            return false;
        }

        $is_connect_admin_page = false;

		if ( ! empty( $page_slug[1] ) && $page_slug[1] === $plugin_page ) {
			$is_connect_admin_page = true;
		}

		if ( ! $is_connect_admin_page && Config::ADMIN_PAGE === $plugin_page ) {
			$is_connect_admin_page = true;
		}

		if ( ! $is_connect_admin_page ) {
			return false;
		}

        $code = $_GET['code'] ?? null;
        $state = $_GET['state'] ?? null;

        if ( empty( $code ) || empty( $state ) ) {
            return false;
        }

        return true;
    }

    public static function validate_nonce( $state ) {
        if ( ! wp_verify_nonce( $state, Config::STATE_NONCE ) ) {
            wp_die( 'Invalid state' );
        }
    }

    public static function handle_auth_code() {
        if ( !self::should_handle_auth_code() ) {
            return;
        }

        $code = sanitize_text_field( $_GET['code'] );
        $state = sanitize_text_field( $_GET['state'] );

        // Check if the state is valid
        self::validate_nonce( $state );

        // authorization exchange step
        try {
            $token = service::get_token(GrantTypes::AUTHORIZATION_CODE, $code);
        } catch (Service_Exception $e) {
            error_log( 'Failed to authenticate, initializing the plugin to try start again.' );
            wp_redirect( Utils::get_redirect_uri() );
        }

        // consider check directly with hydra admin instead of saving redirect_uri on options db
        data::set_auth_redirect_uri();

        // Call hook to Register the current site on collections (site, plugins, forms)
        do_action( 'on_connect_' . Config::APP_PREFIX . '_connected' );

        wp_redirect( Utils::get_redirect_uri() );

        exit;
    }
}
