<?php
namespace Send\Classes\Traits;
use connect\Client;

trait Tracking {

	public static function handleViewedForm($req, $source) {
		$formIdParts = explode('-', $req['formId']);
		$formLocation = $req['formLocation'];
		if (empty($formLocation)) {
			error_log('Form location is required');
			return wp_json_encode(["status" => "error", "message" => "Form location is required"]);
		}
//		error_log('Form location: '.$formLocation);
		$formId = $formIdParts[0];

		$pageUrl = $_SERVER['HTTP_REFERER'];
		$specialType = false;
		switch ($formLocation) {
		case 'popup':
		case 'header':
		case 'footer':
			$specialType = true;
			break;
		default:
			break;
		}





		$pageName = basename(wp_parse_url($pageUrl, PHP_URL_PATH));

		$normalizedHomeUrl = trailingslashit(home_url());
		$normalizedPageUrl = trailingslashit($pageUrl);

		if ($normalizedPageUrl === $normalizedHomeUrl) {
			// Get the ID of the page set as the homepage
			$pageId = get_option('page_on_front');
			// Set page name as 'wp-homepage'
			$pageName = 'wp-homepage';
		} else {
			$pageId = url_to_postid($pageUrl);
			// Check if page ID is 0 and set page name accordingly
			if ($pageId === 0) {
				$pageName = 'wp-homepage';
			}
		}

		$payload = [
			"eventType" => "viewed",
			"formId" => strval($formId),
			'specialType' => $specialType ? $formLocation : null,
			"page" => [
				'pageId' => strval($pageId),
				'name' => strval($pageName),
			],
			'source' => ['method' => 'form', 'name' => $source],
		];

		return self::sendTrackingdata($payload);
	}

	public static function handleAbandonedForm($req, $source) {
		$formIdParts = explode('-', $req['formId']);
		$pageUrl = $_SERVER['HTTP_REFERER'];
		$pageName = basename(wp_parse_url($pageUrl, PHP_URL_PATH));
		$pageId = url_to_postid($pageUrl);
		$formLocation = $req['formLocation'];
		if (empty($formLocation)) {
			error_log('Form location is required');
			return wp_json_encode(["status" => "error", "message" => "Form location is required"]);
		}
		$specialType = false;
		switch ($formLocation) {
		case 'popup':
		case 'header':
		case 'footer':
			$specialType = true;
			break;
		default:
			break;
		}
		$formId = $formIdParts[0];
		$payload = [
			"eventType" => "abandoned",
			"formId" => strval($formId),
			'specialType' => $specialType ? $formLocation : null,
			"page" => [
				'pageId' => strval($pageId),
				'name' => strval($pageName)
			],
			'source' => ['method' => 'form', 'name' => $source],
		];
		return self::sendTrackingdata($payload);
	}

	public static function sendTrackingdata($payload) {
		$payload['siteUrl'] = strval(CURRENT_HOST);
        $client = new Client();
        $response = $client->make_request('POST', API_ENDPOINT . '/events/forms-events/create-form', $payload, [], false, '');
		if (!is_wp_error($response)) {
			return wp_json_encode(["status" => "ok"]);
		}
		return wp_json_encode(["status" => "error"]);
	}
}
