<?php

namespace Send\Classes\Traits;

use connect\Client;
use Send\Classes\Integrations\WooCommerce\Module;

trait Woo {

	public static function get_updates_endpoint( $action ): string {
		return API_ENDPOINT . '/woo/metadata/' . $action;
	}

	public static function get_initial_sync_endpoint( $entity ): string {
		return API_ENDPOINT . '/woo/sync/' . $entity;
	}

    public static function sendMetaData($payload, $dataType, $action, $method = 'POST') {
        $request_payload = [
            'siteUrl' => strval(CURRENT_HOST),
            'dataType' => $dataType,
            "data" => $payload
        ];

        $client = new Client();

        return $client->make_request($method, static::get_updates_endpoint( $action ) , $request_payload, [], false, '');
    }

    public static function sendInitialSyncData($payload, $dataType, string $entity, $method = 'POST') {
        $request_payload = [
            'siteUrl' => strval(CURRENT_HOST),
            'dataType' => $dataType,
            'data' => $payload
        ];
        
        $client = new Client();

        return $client->make_request($method, static::get_initial_sync_endpoint( $entity ), $request_payload, [], false, '');
    }

    // special function to delay the execution of the onNewOrder function - because the data will only be in the database after a few seconds
    public static function delayOnNewOrderExecution( $seconds, $order, $customerDetails ) {
        ignore_user_abort( true ); // Continue running script even if client aborts
        // Now execute your order processing logic
	    Module::instance()->get_component( 'WooOrders' )->onNewOrder( $order, $customerDetails );
    }

    public static function updateSiteCurrency()
    {
        $currency = 'USD';
        if (function_exists('get_woocommerce_currency')) {
            $currency = get_woocommerce_currency();
        }
        $request_payload = [
            'currency' => $currency,
        ];
        $client = new Client();
        return $client->make_request('POST', API_ENDPOINT . '/woo/update-currency', $request_payload, [], false, '');
    }

    public static function sendWooEmail($emailType) {
        $client = new client();
        $client->make_request('POST', API_ENDPOINT . '/woo/send-email', ['action' => 'sync-finished'], [], false, '');
    }

    public static function fullSync(): array {
	    $woo_products = Module::instance()->get_component( 'WooProducts' );
	    $syncStatus['products'] = $woo_products->register_sync( true );

	    $woo_orders = Module::instance()->get_component( 'WooOrders' );
	    $syncStatus['orders'] = $woo_orders->register_sync( true );
        
        $syncStatus['contacts'] = true;

        // TODO: return error of failed to write the first action scheduler
        return $syncStatus;
    }
}
