<?php
namespace Send\Classes\Rest;
use connect\classes\data;
use connect\classes\service;
use connect\Client;
use connect\classes\Utils;
use Send\Classes\Integrations\Integrations;
use Send\Classes\Traits\Tracking;
use Send\Classes\Traits\Woo;
use connect\Module as ConnectSDK;

$routes = new Routes();


/*
 *** 						***
 *** 	   CF7 Routes     	***
 *** 						***
 */

$routes->post('/cf7/viewed', function ($data) {
	return Tracking::handleViewedForm($data, 'cf7');
});

$routes->post('/cf7/abandoned', function ($data) {
	return Tracking::handleAbandonedForm($data,'cf7');
});


/*
 *** 						***
 *** 	WPForms Routes 		***
 *** 						***
 */

$routes->post('/wpforms/viewed', function ($data) {
	return Tracking::handleViewedForm($data,'wpforms');
});

$routes->post('/wpforms/abandoned', function ($data) {
	return Tracking::handleAbandonedForm($data,'wpforms');
});



/*
 *** 						***
 *** 	Elementor Routes 	***
 *** 						***
 */

$routes->post('/elementor/abandoned', function ($data) {
	return Tracking::handleAbandonedForm($data,'elementor');
});

$routes->post('/elementor/viewed', function ($data) {
	return Tracking::handleViewedForm($data,'elementor');
});

// Define routes
$routes->post('/user/behavior', function ($data) {
	$user_session = wp_get_session_token();
	$data['session_id'] = $user_session;
	$user = wp_get_current_user(); // Get current user info
	$data['userData'] = $user;
	unset($data['userData']->user_pass);
//	error_log('User behavior data: '.wp_json_encode($data));
});

/*
 *** 						***
 *** 	General Routes 		***
 *** 						***
 */


// Define stream routes - routes that ths application needs to listen to always.
$routes->get('/integrations', function () {
	$activeIntegrations = Integrations::getAllSupportedActiveIntegrations();
    $noneActiveIntegrations = Integrations::getSupportedInstalledOnlyIntegrations();
    $plugins = array_merge($activeIntegrations, $noneActiveIntegrations);
	return ["plugins" => $plugins ];
});

$routes->get('/get-integrations-status', function () {
   return Integrations::getStatusBySourceId();
});

$routes->get('/forms', function () {
	return Integrations::sendFormsData();
});

/* Woocommerce */
$routes->get('/sync-woo', function () {
	$response = Woo::fullSync();
    return $response;
});


/*
 *** 						***
 *** 	Plugins State  		***
 *** 						***
 */

$routes->post('/activate-plugin', function ($data) {
    return Integrations::activate($data);
});

$routes->post('/connect-plugin', function ($data) {
	$response = Integrations::connect($data);
	echo wp_json_encode($response);

	// Stop further execution
	return;
});

$routes->post('/create-plugin-forms', function () {
	$response = Integrations::sendFormsData();
	Woo::updateSiteCurrency();

	echo wp_json_encode($response);

	// Stop further execution
	return;
});

$routes->post('/disconnect-plugin', function ($data) {
	return Integrations::disconnect($data);
});

$routes->get('/refresh-token', function() {
    if (!ConnectSDK::is_connected()) {
        return ['error' => 'Not connected'];
    }
    // refresh via client request
    try {
        service::refresh_token();
    } catch (\Exception $e) {
        return ['error' => $e->getMessage()];
    }

    // Define the headers array
    $headers = [
        'Authorization' => 'Bearer ' . data::get_access_token(),
        'x-elementor-send' => SEND_VERSION,
        'x-elementor-apps' => 'send',
    ];

    return [
        'headers' => $headers
    ];
});


$routes->get('/init', function() {
    // Preparation for moving connect logic to app
    $data = [
        'siteUrl' => CURRENT_HOST,
        'isConnected' => ConnectSDK::is_connected(),
        'siteId' => data::get_client_id(),
        'isValidRedirectUri' => Utils::is_valid_auth_redirect_uri(),
    ];

    Integrations::sendFormsData();
    // Define the headers array
    $headers = [
        'Authorization' => 'Bearer ' . data::get_access_token(),
        'x-elementor-send' => SEND_VERSION,
        'x-elementor-apps' => 'send',
    ];

    $storeCurrency = 'USD'; // default
    if (function_exists('get_woocommerce_currency')) {
        $storeCurrency = get_woocommerce_currency();
    }
    return [
        'headers' => $headers,
        'siteData' => $data,
		'storeCurrency' => $storeCurrency,
    ];
});


$routes->get('/reconnect', function () {
    // we must not allow reconnection if the user is already connected -> return
    return ['redirect' => true];
});

$routes->register();
