<?php

use Send\Classes\Database\Database;
use Illuminate\Database\Query\Builder;

// Define WordPress database constants for testing
define('DB_HOST', 'localhost');
define('DB_NAME', 'test_database');
define('DB_USER', 'test_user');
define('DB_PASSWORD', 'test_password');
define('DB_CHARSET', 'utf8');

// Mocking global $wpdb
global $wpdb;
$wpdb = new stdClass();

// Define $wpdb->prefix for testing
$wpdb->prefix = 'wp_';

// Mocking plugins_url function
function plugins_url($path = '', $plugin = '') {
	return "http://example.com/{$path}";
}

it('executes a query', function () {
	// Mocking a query builder instance
	$query = Mockery::mock(Builder::class);
	$query->shouldReceive('toSql')->andReturn('SELECT * FROM table WHERE id = ?');
	$query->shouldReceive('getBindings')->andReturn([1]);
	
	// Mocking $wpdb->get_results() method
	global $wpdb;
	$wpdb = Mockery::mock('alias:wpdb');
	$wpdb->prefix = 'wp_'; // Set prefix property on the $wpdb mock object
	$wpdb->shouldReceive('get_results')->once()->andReturn(['result1', 'result2']);
	
	// Mocking $wpdb->prepare() method
	$wpdb->shouldReceive('prepare')->andReturnUsing(function ($format) {
		$args = func_get_args();
		$args = array_slice($args, 1); // Exclude the $format argument
		return vsprintf($format, $args);
	});
	
	$results = Database::execute($query);
	
	expect($results)->toEqual(['result1', 'result2']);
});

it('extracts a field from results', function () {
	$res = [
		(object) ['id' => 1, 'name' => 'John'],
		(object) ['id' => 2, 'name' => 'Jane']
	];
	
	$field = Database::field('name', $res);
	
	expect($field)->toEqual(['John', 'Jane']);
});
